###############################
# Liver Consomics
# Repeat tests for CHR15, CHR6
# NOVEMBER 14, 2005
# Churchill/Shockley
# R/maanova version 0.98-7
###############################

#Set the working directory and place the design files and normalized data into the working directory
setwd("C:/TEST_CSSpaper");

#load R/maanova
library(maanova); Rmaanova.version();

#Read the data into R/maanova
raw.data = read.madata("data.norm_repeated_liver_samples.dat", 
           designfile="design_repeated_liver_samples.dat", cloneid=1, pmt=2, spot=F);
data = createData(raw.data, n.rep=1, log.tran=F);

#Load "liver_outliers.Rdata" object. This contains the 185 outlier probesets.
load("C:/TEST_CSSpaper/liver_outliers.Rdata")

#Find all probe sets to be analyzed in this study
x = 1
filterdata = vector(length=0);
for(i in 1:45101){
    if(any(liver_outliers == i)){print(i)}
    else{filterdata[x] = i; x = x+1}
}

#Filter the data to analyze only the 44,916 remaining genes using the R/maanova subset function
data.filter = subset.madata(data, genes=filterdata);

#Subset the data into two B.AN strain groups
data.B6B6_ind = subset.madata(data.filter, c(9:12, 1:4));
data.B6B15_ind = subset.madata(data.filter, c(5:8, 1:4));

DATA = list(data.B6B6_ind, data.B6B15_ind);

#############
# test STRAIN
#############
ftest.strain.Ptab = matrix(0, nrow=44916, ncol=2); ftest.strain.Pvalperm = matrix(0, nrow=44916, ncol=2);
colnames(ftest.strain.Pvalperm) = c("B.A6", "B.A15");

for(i in 1:2){
    model.tmp = makeModel(data=DATA[[i]], formula=~Sex + Strain);
    test.tmp = matest(DATA[[i]], model.tmp, term="Strain", shuffle.method="resid", n.perm=1000, pval.pool=TRUE);
    ftest.strain.Ptab[,i] = test.tmp$Fs$Ptab; ftest.strain.Pvalperm[,i] = test.tmp$Fs$Pvalperm;
}

##########
# test SEX
##########
ftest.sex.Ptab = matrix(0, nrow=44916, ncol=2); ftest.sex.Pvalperm = matrix(0, nrow=44916, ncol=2);
colnames(ftest.sex.Pvalperm) = c("B.A6", "B.A15");

for(i in 1:2){
    model.tmp = makeModel(data=DATA[[i]], formula=~Sex + Strain);
    test.tmp = matest(DATA[[i]], model.temp1, term="Sex", shuffle.method="resid", n.perm=1000, pval.pool=TRUE);
    ftest.sex.Ptab[,i] = test.tmp$Fs$Ptab;
    ftest.sex.Pvalperm[,i] = test.tmp$Fs$Pvalperm;
}

##################
# test INTERACTION
##################
ftest.int.Ptab = matrix(0, nrow=44916, ncol=2); ftest.int.Pvalperm = matrix(0, nrow=44916, ncol=2);
colnames(ftest.int.Pvalperm) = c("B.A6", "B.A15");

for(i in 1:2){
    model.tmp = makeModel(data=DATA[[i]], formula=~Sex + Strain + Sex:Strain);
    test.tmp = matest(DATA[[i]], model.tmp, term="Sex:Strain", shuffle.method="resid", n.perm=1000, pval.pool=TRUE);
    ftest.int.Ptab[,i] = test.tmp$Fs$Ptab; ftest.int.Pvalperm[,i] = test.tmp$Fs$Pvalperm;
}

#####################################
# Calculate FDR using Storey's method
#####################################

library(qvalue);

vector.strain = as.vector(ftest.strain.Pvalperm);
q.pool.strain.temp = qvalue(vector.strain)$qvalues
q.pool.strain = matrix(q.pool.strain.temp, nrow=44916, ncol=2);

vector.sex = as.vector(ftest.sex.Pvalperm);
q.pool.sex.temp = qvalue(vector.sex)$qvalues;
q.pool.sex = matrix(q.pool.sex.temp, nrow=44916, ncol=2);

vector.int = as.vector(ftest.int.Pvalperm);
q.pool.int.temp = qvalue(vector.int)$qvalues;
q.pool.int = matrix(q.pool.int.temp, nrow=44916, ncol=2);

